# swagger_client

SwaggerClient - the Ruby gem for the SimplyRETS API

The SimplyRETS API is an exciting step towards making it easier for developers and real estate agents to build something awesome with real estate data!  The documentation below makes live requests to our API using the trial data. To get set up with the API using live MLS data, you must have RETS credentials from your MLS, which you can then use to create an app with SimplyRETS. For more information on that process, please see our [FAQ](https://simplyrets.com/faq), [Getting Started](https://simplyrets.com/blog/getting-set-up.html) page, or [contact us](https://simplyrets.com/\\#home-contact).  Below you'll find the API endpoints, query parameters, response bodies, and other information about using the SimplyRETS API. You can run queries by clicking the 'Try it Out' button at the bottom of each section.  ### Authentication The SimplyRETS API uses Basic Authentication. When you create an app, you'll get a set of API credentials to access your listings. If you're trying out the test data, you can use `simplyrets:simplyrets` for connecting to the API.  ### Media Types The SimplyRETS API uses the `Accept` header to allow clients to control media types (content versions). We maintain backwards compatibility with API clients by allowing them to specify a content version. We highly recommend setting and explicity media type when your application reaches production. Both the structure and content of our API response bodies is subject to change so we can add new features while respecting the stability of applications which have already been developed.  To always use the latest SimplyRETS content version, simply use `application/json` in your application `Accept` header.  If you want to pin your clients media type to a specific version, you can use the vendor-specific SimplyRETS media type, e.g. `application/vnd.simplyrets-v0.1+json\"`  To view all valid content-types for making an `OPTIONS`, make a request to the SimplyRETS api root  `curl -XOPTIONS -u simplyrets:simplyrets https://api.simplyrets.com/`  The default media types used in our API responses may change in the future. If you're building an application and care about the stability of the API, be sure to request a specific media type in the Accept header as shown in the examples below.  The wordpress plugin automatically sets the `Accept` header for the compatible SimplyRETS media types.  ### Pagination There a few pieces of useful information about each request stored in the HTTP Headers:  - `X-Total-Count` shows you the total amount of listings that match   your current query. - `Link` contains pre-built pagination links for accessing the next 'page' of listings that match your query. Read more about that [here](https://simplyrets.com/blog/api-pagination.html). 

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build date: 2016-06-23T15:05:38.324Z
- Build package: class io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build swagger_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./swagger_client-1.0.0.gem
```
(for development, run `gem install --dev ./swagger_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'swagger_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO, then add the following in the Gemfile:

    gem 'swagger_client', :git => 'https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'swagger_client'

# Setup authorization
SwaggerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = SwaggerClient::DefaultApi.new

opts = { 
  type: "type_example", # String | Request listings by a specific property type. This defaults to Residential, and you can only specify one type in a single query. 
  listing_id: "listing_id_example", # String | Request openhouses for a specific `listingId`. 
  cities: ["cities_example"], # Array<String> | Filter the openhouses returned by a list of valid cities. A list of valid cities can be found by making an OPTIONS request to the `/openhouses` endpoint. 
  brokers: ["brokers_example"], # Array<String> | Filter the listings returned by brokerage with a Broker ID. You can specific multiple broker parameters. Note, the Broker ID is provided by your MLS. 
  agent: "agent_example", # String | Filter the listings returned by an agent ID.  Note, the Agent ID is provided by your MLS. 
  minprice: 56, # Integer | Filter listings by a minimum price. 
  startdate: DateTime.parse("2013-10-20T19:20:30+01:00"), # DateTime | Scheduled date and time of the open house showing
  offset: 56, # Integer | Used as a cursor for pagination. Increase the offset parameter by the limit to go to the next \"page\" of listings. Also take a look at the Link HTTP Header for pre-built pagination. 
  limit: 56, # Integer | Set the number of listings to return in the response. This defaults to 20 listings, and can be a maximum of 50. To paginate through to the next page of listings, take a look at the `offset` parameter, or the Link in the HTTP Header. 
  sort: "sort_example", # String | Sort the response by a specific field. Values starting with a minus (-) denote descending order, while the others are ascending. 
  include: ["include_example"] # Array<String> | Include a extra fields which are not in the default response body - 'association' includes additional HOA data - 'agreement' information on the listing agreement - 'garageSpaces' additional garage data - 'maintenanceExpense' data on maintenance expenses - 'parking' additional parking data - 'pool' includes an additional pool description - 'taxAnnualAmount' include the annual tax amount - 'taxYear' include the tax year data - 'rooms' include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  In the future, fields which require an 'include' may become available by default. 
}

begin
  #The SimplyRETS OpenHouses API
  result = api_instance.openhouses_get(opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling DefaultApi->openhouses_get: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.simplyrets.com/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SwaggerClient::DefaultApi* | [**openhouses_get**](docs/DefaultApi.md#openhouses_get) | **GET** /openhouses | The SimplyRETS OpenHouses API
*SwaggerClient::DefaultApi* | [**openhouses_open_house_key_get**](docs/DefaultApi.md#openhouses_open_house_key_get) | **GET** /openhouses/{openHouseKey} | Single OpenHouse Endpoint
*SwaggerClient::DefaultApi* | [**properties_get**](docs/DefaultApi.md#properties_get) | **GET** /properties | The SimplyRETS Listings API
*SwaggerClient::DefaultApi* | [**properties_mls_id_get**](docs/DefaultApi.md#properties_mls_id_get) | **GET** /properties/{mlsId} | Single Listing Endpoint


## Documentation for Models

 - [SwaggerClient::Agent](docs/Agent.md)
 - [SwaggerClient::Broker](docs/Broker.md)
 - [SwaggerClient::ContactInformation](docs/ContactInformation.md)
 - [SwaggerClient::Error](docs/Error.md)
 - [SwaggerClient::GeographicData](docs/GeographicData.md)
 - [SwaggerClient::Listing](docs/Listing.md)
 - [SwaggerClient::MlsInformation](docs/MlsInformation.md)
 - [SwaggerClient::Office](docs/Office.md)
 - [SwaggerClient::OpenHouse](docs/OpenHouse.md)
 - [SwaggerClient::Parking](docs/Parking.md)
 - [SwaggerClient::Property](docs/Property.md)
 - [SwaggerClient::Sales](docs/Sales.md)
 - [SwaggerClient::School](docs/School.md)
 - [SwaggerClient::StreetAddress](docs/StreetAddress.md)
 - [SwaggerClient::Tax](docs/Tax.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

