# SwaggerClient::DefaultApi

All URIs are relative to *https://api.simplyrets.com/*

Method | HTTP request | Description
------------- | ------------- | -------------
[**openhouses_get**](DefaultApi.md#openhouses_get) | **GET** /openhouses | The SimplyRETS OpenHouses API
[**openhouses_open_house_key_get**](DefaultApi.md#openhouses_open_house_key_get) | **GET** /openhouses/{openHouseKey} | Single OpenHouse Endpoint
[**properties_get**](DefaultApi.md#properties_get) | **GET** /properties | The SimplyRETS Listings API
[**properties_mls_id_get**](DefaultApi.md#properties_mls_id_get) | **GET** /properties/{mlsId} | Single Listing Endpoint


# **openhouses_get**
> Array&lt;OpenHouse&gt; openhouses_get(opts)

The SimplyRETS OpenHouses API

This is the main endpoint for accessing openhouses. 

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = SwaggerClient::DefaultApi.new

opts = { 
  type: "type_example", # String | Request listings by a specific property type. This defaults to Residential, and you can only specify one type in a single query. 
  listing_id: "listing_id_example", # String | Request openhouses for a specific `listingId`. 
  cities: ["cities_example"], # Array<String> | Filter the openhouses returned by a list of valid cities. A list of valid cities can be found by making an OPTIONS request to the `/openhouses` endpoint. 
  brokers: ["brokers_example"], # Array<String> | Filter the listings returned by brokerage with a Broker ID. You can specific multiple broker parameters. Note, the Broker ID is provided by your MLS. 
  agent: "agent_example", # String | Filter the listings returned by an agent ID.  Note, the Agent ID is provided by your MLS. 
  minprice: 56, # Integer | Filter listings by a minimum price. 
  startdate: DateTime.parse("2013-10-20T19:20:30+01:00"), # DateTime | Scheduled date and time of the open house showing
  offset: 56, # Integer | Used as a cursor for pagination. Increase the offset parameter by the limit to go to the next \"page\" of listings. Also take a look at the Link HTTP Header for pre-built pagination. 
  limit: 56, # Integer | Set the number of listings to return in the response. This defaults to 20 listings, and can be a maximum of 50. To paginate through to the next page of listings, take a look at the `offset` parameter, or the Link in the HTTP Header. 
  sort: "sort_example", # String | Sort the response by a specific field. Values starting with a minus (-) denote descending order, while the others are ascending. 
  include: ["include_example"] # Array<String> | Include a extra fields which are not in the default response body - 'association' includes additional HOA data - 'agreement' information on the listing agreement - 'garageSpaces' additional garage data - 'maintenanceExpense' data on maintenance expenses - 'parking' additional parking data - 'pool' includes an additional pool description - 'taxAnnualAmount' include the annual tax amount - 'taxYear' include the tax year data - 'rooms' include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  In the future, fields which require an 'include' may become available by default. 
}

begin
  #The SimplyRETS OpenHouses API
  result = api_instance.openhouses_get(opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling DefaultApi->openhouses_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **type** | **String**| Request listings by a specific property type. This defaults to Residential, and you can only specify one type in a single query.  | [optional] 
 **listing_id** | **String**| Request openhouses for a specific &#x60;listingId&#x60;.  | [optional] 
 **cities** | [**Array&lt;String&gt;**](String.md)| Filter the openhouses returned by a list of valid cities. A list of valid cities can be found by making an OPTIONS request to the &#x60;/openhouses&#x60; endpoint.  | [optional] 
 **brokers** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by brokerage with a Broker ID. You can specific multiple broker parameters. Note, the Broker ID is provided by your MLS.  | [optional] 
 **agent** | **String**| Filter the listings returned by an agent ID.  Note, the Agent ID is provided by your MLS.  | [optional] 
 **minprice** | **Integer**| Filter listings by a minimum price.  | [optional] 
 **startdate** | **DateTime**| Scheduled date and time of the open house showing | [optional] 
 **offset** | **Integer**| Used as a cursor for pagination. Increase the offset parameter by the limit to go to the next \&quot;page\&quot; of listings. Also take a look at the Link HTTP Header for pre-built pagination.  | [optional] 
 **limit** | **Integer**| Set the number of listings to return in the response. This defaults to 20 listings, and can be a maximum of 50. To paginate through to the next page of listings, take a look at the &#x60;offset&#x60; parameter, or the Link in the HTTP Header.  | [optional] 
 **sort** | **String**| Sort the response by a specific field. Values starting with a minus (-) denote descending order, while the others are ascending.  | [optional] 
 **include** | [**Array&lt;String&gt;**](String.md)| Include a extra fields which are not in the default response body - &#39;association&#39; includes additional HOA data - &#39;agreement&#39; information on the listing agreement - &#39;garageSpaces&#39; additional garage data - &#39;maintenanceExpense&#39; data on maintenance expenses - &#39;parking&#39; additional parking data - &#39;pool&#39; includes an additional pool description - &#39;taxAnnualAmount&#39; include the annual tax amount - &#39;taxYear&#39; include the tax year data - &#39;rooms&#39; include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  In the future, fields which require an &#39;include&#39; may become available by default.  | [optional] 

### Return type

[**Array&lt;OpenHouse&gt;**](OpenHouse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json, application/vnd.simplyrets-v0.1+json



# **openhouses_open_house_key_get**
> OpenHouse openhouses_open_house_key_get(open_house_key, opts)

Single OpenHouse Endpoint

Use this endpoint for accessing a single OpenHouse. 

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = SwaggerClient::DefaultApi.new

open_house_key = 789 # Integer | A unique OpenHouse identification key

opts = { 
  include: ["include_example"] # Array<String> | Include a extra fields which are not in the default response body - 'association' includes additional HOA data - 'agreement' information on the listing agreement - 'garageSpaces' additional garage data - 'maintenanceExpense' data on maintenance expenses - 'parking' additional parking data - 'pool' includes an additional pool description - 'taxAnnualAmount' include the annual tax amount - 'taxYear' include the tax year data - 'rooms' include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  In the future, fields which require an 'include' may become available by default. 
}

begin
  #Single OpenHouse Endpoint
  result = api_instance.openhouses_open_house_key_get(open_house_key, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling DefaultApi->openhouses_open_house_key_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **open_house_key** | **Integer**| A unique OpenHouse identification key | 
 **include** | [**Array&lt;String&gt;**](String.md)| Include a extra fields which are not in the default response body - &#39;association&#39; includes additional HOA data - &#39;agreement&#39; information on the listing agreement - &#39;garageSpaces&#39; additional garage data - &#39;maintenanceExpense&#39; data on maintenance expenses - &#39;parking&#39; additional parking data - &#39;pool&#39; includes an additional pool description - &#39;taxAnnualAmount&#39; include the annual tax amount - &#39;taxYear&#39; include the tax year data - &#39;rooms&#39; include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  In the future, fields which require an &#39;include&#39; may become available by default.  | [optional] 

### Return type

[**OpenHouse**](OpenHouse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json, application/vnd.simplyrets-v0.1+json



# **properties_get**
> Array&lt;Listing&gt; properties_get(opts)

The SimplyRETS Listings API

This is the main endpoint for accessing your properties. View all of the available query parameters and make requests below! The API uses Basic Authentication, which most HTTP libraries will handle for you. To use the test data (which is what this pages uses), you can use the api key `simplyrets` and secret `simplyrets`. Note that these test listings are not live MLS listings but the data, query parameters, and response bodies will all work the same. 

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = SwaggerClient::DefaultApi.new

opts = { 
  q: "q_example", # String | A textual keyword search. This parameter will search  the following fields, when available:   - listingId (This does _not_ search the `mlsId` field in the SimplyRETS response body)   - street number   - street name   - mls area (major)   - city   - subdivision name   - postal code 
  status: ["status_example"], # Array<String> | Request listings by a specific status. This parameter defaults to active and you can specify multiple statuses in a single query.  Listing statuses depend on your MLS's availability. Below is a brief description of each status with possible synonyms which may map to your MLS-specific statuses - *Active*: Active Listing which is still on the market - *ActiveUnderContract*: An offer has been accepted but the listing is still on market. Synonyms: Accepting Backup Offers, Backup Offer, Active With Accepted. Synonyms: Offer, Backup, Contingent - *Pending*: An offer has been accepted and the listing is no longer on market. Synonyms: Offer Accepted, Under Contract - *Hold*: The listing has been withdrawn from the market, but a contract   still exists between the seller and the listing member. Synonyms: Hold, Hold Do Not Show, Temp Off Market - *Withdrawn*: The listing has been withdrawn from the market, but a contract   still exists between the seller and the listing member. Synonyms: Hold, Hold Do Not Show, Temp Off Market - *Closed*: The purchase agreement has been fulfilled or the lease   agreement has been executed. Synonyms: Sold, Leased, Rented, Closed Sale - *Expired*: The listing contract has expired - *Delete*: The listing contract was never valid or other reason for the contract to be nullified. Synonyms: Kill, Zap - *Incomplete*: The listing has not yet be completely entered and is not yet   published in the MLS. Synonyms: Draft, Partially Complted - *ComingSoon* 
  type: ["type_example"], # Array<String> | Request listings by a specific property type. This defaults to Residential and Rental. You can specify multiple property types in a single query. 
  agent: "agent_example", # String | Filter the listings returned by an agent ID.  Note, the Agent ID is provided by your MLS.  The co-listing agent is not included in this query parameter. 
  brokers: ["brokers_example"], # Array<String> | Filter the listings returned by brokerage with a Broker ID. For some MLS areas, this is the ListOfficeId (Listing Office ID).  You can specific multiple broker parameters. Note, this query parameter is only available if a Broker ID is provided by your MLS. 
  minprice: 56, # Integer | Filter listings by a minimum price. 
  maxprice: 56, # Integer | Filter listings by a maximum price 
  minarea: 56, # Integer | Filter listings by a minimum area size in Sq Ft. 
  maxarea: 56, # Integer | Filter listings by a maximum area size in Sq Ft. 
  minbaths: 56, # Integer | Filter listings by a minimum number of bathrooms. 
  maxbaths: 56, # Integer | Filter listings by a maximum number of bathrooms. 
  minbeds: 56, # Integer | Filter listings by a minimum number of bedrooms. 
  maxbeds: 56, # Integer | Filter listings by a maximum number of bedrooms. 
  maxdom: 56, # Integer | Filter listings by a maximum number of days on market. _Note that your MLS must provide Days on Market data._ 
  minyear: 56, # Integer | Filter listings by a setting a minimum year built. 
  limit: 56, # Integer | Set the number of listings to return in the response. This defaults to 20 listings, and can be a maximum of 50. To paginate through to the next page of listings, take a look at the `offset` parameter, or the Link in the HTTP Header. 
  offset: 56, # Integer | Used as a cursor for pagination. Increase the offset parameter by the limit to go to the next \"page\" of listings. Also take a look at the Link HTTP Header for pre-built pagination.  *NOTE:* If you're offset is too high, you will receive an `HTTP 400 offset too high` error message. 
  vendor: "vendor_example", # String | Used to specify the vendor (MLS) to search from. This parameter is required on multi-MLS apps, and you can only query one vendor at a time. To get your vendor id's make an OPTIONS request to https://api.simplyrets.com. 
  postal_codes: ["postal_codes_example"], # Array<String> | Filter the listings returned by postal codes / zip code. You can specify multiple. 
  features: ["features_example"], # Array<String> | Filter the listings by specific interior features.  You can filter by multiple. For example, to filter trial listings by multiple features you can use, Return listings that are within a set of latitude longitude coordinates. For example,  ``` Wet Bar High Ceiling ```  e.g. `https://simplyrets.com/services?features=Wet%20Bar&features=High%20Ceiling`  The features provided by your MLS can be seen in your OPTIONS request. To view all valid features, make a request to the SimplyRETS api root  `curl -XOPTIONS -u simplyrets:simplyrets https://api.simplyrets.com/` 
  water: "water_example", # String | Query water/waterfront listings only. Specify `true` to filter waterfront listings. 
  neighborhoods: ["neighborhoods_example"], # Array<String> | Filter the listings returned by specific neighborhoods and subdivisions. You can specify multiple. 
  cities: ["cities_example"], # Array<String> | Filter the listings returned by specific cities. You can specify multiple. 
  counties: ["counties_example"], # Array<String> | Filter the listings returned by specific counties. You can specify multiple. 
  points: ["points_example"], # Array<String> | Return listings that are within a set of latitude longitude coordinates. For example; ``` 29.723837,-95.69778 29.938275,-95.69778 29.938275,-95.32974 29.723837,-95.32974 ``` Note that some MLS's do not provide latitude and longitude for their listings, which is required for this parameter to work. In these cases, SimplyRETS offers a [Geocoding Addon](https://simplyrets.com/services#geocoding).  Check out our [blog post](https://simplyrets.com/blog/interactive-map-search.html) on using the `points` parameter to build a map-based app in javascript. 
  include: ["include_example"], # Array<String> | Include a extra fields which are not in the default response body - 'association' includes additional HOA data - 'agreement' information on the listing agreement - 'garageSpaces' additional garage data - 'maintenanceExpense' data on maintenance expenses - 'parking' additional parking data - 'pool' includes an additional pool description - 'taxAnnualAmount' include the annual tax amount - 'taxYear' include the tax year data - 'rooms' include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response. 
  sort: "sort_example" # String | Sort the response by a specific field. Values starting with a minus (-) denote descending order, while the others are ascending. 
}

begin
  #The SimplyRETS Listings API
  result = api_instance.properties_get(opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling DefaultApi->properties_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **q** | **String**| A textual keyword search. This parameter will search  the following fields, when available:   - listingId (This does _not_ search the &#x60;mlsId&#x60; field in the SimplyRETS response body)   - street number   - street name   - mls area (major)   - city   - subdivision name   - postal code  | [optional] 
 **status** | [**Array&lt;String&gt;**](String.md)| Request listings by a specific status. This parameter defaults to active and you can specify multiple statuses in a single query.  Listing statuses depend on your MLS&#39;s availability. Below is a brief description of each status with possible synonyms which may map to your MLS-specific statuses - *Active*: Active Listing which is still on the market - *ActiveUnderContract*: An offer has been accepted but the listing is still on market. Synonyms: Accepting Backup Offers, Backup Offer, Active With Accepted. Synonyms: Offer, Backup, Contingent - *Pending*: An offer has been accepted and the listing is no longer on market. Synonyms: Offer Accepted, Under Contract - *Hold*: The listing has been withdrawn from the market, but a contract   still exists between the seller and the listing member. Synonyms: Hold, Hold Do Not Show, Temp Off Market - *Withdrawn*: The listing has been withdrawn from the market, but a contract   still exists between the seller and the listing member. Synonyms: Hold, Hold Do Not Show, Temp Off Market - *Closed*: The purchase agreement has been fulfilled or the lease   agreement has been executed. Synonyms: Sold, Leased, Rented, Closed Sale - *Expired*: The listing contract has expired - *Delete*: The listing contract was never valid or other reason for the contract to be nullified. Synonyms: Kill, Zap - *Incomplete*: The listing has not yet be completely entered and is not yet   published in the MLS. Synonyms: Draft, Partially Complted - *ComingSoon*  | [optional] 
 **type** | [**Array&lt;String&gt;**](String.md)| Request listings by a specific property type. This defaults to Residential and Rental. You can specify multiple property types in a single query.  | [optional] 
 **agent** | **String**| Filter the listings returned by an agent ID.  Note, the Agent ID is provided by your MLS.  The co-listing agent is not included in this query parameter.  | [optional] 
 **brokers** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by brokerage with a Broker ID. For some MLS areas, this is the ListOfficeId (Listing Office ID).  You can specific multiple broker parameters. Note, this query parameter is only available if a Broker ID is provided by your MLS.  | [optional] 
 **minprice** | **Integer**| Filter listings by a minimum price.  | [optional] 
 **maxprice** | **Integer**| Filter listings by a maximum price  | [optional] 
 **minarea** | **Integer**| Filter listings by a minimum area size in Sq Ft.  | [optional] 
 **maxarea** | **Integer**| Filter listings by a maximum area size in Sq Ft.  | [optional] 
 **minbaths** | **Integer**| Filter listings by a minimum number of bathrooms.  | [optional] 
 **maxbaths** | **Integer**| Filter listings by a maximum number of bathrooms.  | [optional] 
 **minbeds** | **Integer**| Filter listings by a minimum number of bedrooms.  | [optional] 
 **maxbeds** | **Integer**| Filter listings by a maximum number of bedrooms.  | [optional] 
 **maxdom** | **Integer**| Filter listings by a maximum number of days on market. _Note that your MLS must provide Days on Market data._  | [optional] 
 **minyear** | **Integer**| Filter listings by a setting a minimum year built.  | [optional] 
 **limit** | **Integer**| Set the number of listings to return in the response. This defaults to 20 listings, and can be a maximum of 50. To paginate through to the next page of listings, take a look at the &#x60;offset&#x60; parameter, or the Link in the HTTP Header.  | [optional] 
 **offset** | **Integer**| Used as a cursor for pagination. Increase the offset parameter by the limit to go to the next \&quot;page\&quot; of listings. Also take a look at the Link HTTP Header for pre-built pagination.  *NOTE:* If you&#39;re offset is too high, you will receive an &#x60;HTTP 400 offset too high&#x60; error message.  | [optional] 
 **vendor** | **String**| Used to specify the vendor (MLS) to search from. This parameter is required on multi-MLS apps, and you can only query one vendor at a time. To get your vendor id&#39;s make an OPTIONS request to https://api.simplyrets.com.  | [optional] 
 **postal_codes** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by postal codes / zip code. You can specify multiple.  | [optional] 
 **features** | [**Array&lt;String&gt;**](String.md)| Filter the listings by specific interior features.  You can filter by multiple. For example, to filter trial listings by multiple features you can use, Return listings that are within a set of latitude longitude coordinates. For example,  &#x60;&#x60;&#x60; Wet Bar High Ceiling &#x60;&#x60;&#x60;  e.g. &#x60;https://simplyrets.com/services?features&#x3D;Wet%20Bar&amp;features&#x3D;High%20Ceiling&#x60;  The features provided by your MLS can be seen in your OPTIONS request. To view all valid features, make a request to the SimplyRETS api root  &#x60;curl -XOPTIONS -u simplyrets:simplyrets https://api.simplyrets.com/&#x60;  | [optional] 
 **water** | **String**| Query water/waterfront listings only. Specify &#x60;true&#x60; to filter waterfront listings.  | [optional] 
 **neighborhoods** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by specific neighborhoods and subdivisions. You can specify multiple.  | [optional] 
 **cities** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by specific cities. You can specify multiple.  | [optional] 
 **counties** | [**Array&lt;String&gt;**](String.md)| Filter the listings returned by specific counties. You can specify multiple.  | [optional] 
 **points** | [**Array&lt;String&gt;**](String.md)| Return listings that are within a set of latitude longitude coordinates. For example; &#x60;&#x60;&#x60; 29.723837,-95.69778 29.938275,-95.69778 29.938275,-95.32974 29.723837,-95.32974 &#x60;&#x60;&#x60; Note that some MLS&#39;s do not provide latitude and longitude for their listings, which is required for this parameter to work. In these cases, SimplyRETS offers a [Geocoding Addon](https://simplyrets.com/services#geocoding).  Check out our [blog post](https://simplyrets.com/blog/interactive-map-search.html) on using the &#x60;points&#x60; parameter to build a map-based app in javascript.  | [optional] 
 **include** | [**Array&lt;String&gt;**](String.md)| Include a extra fields which are not in the default response body - &#39;association&#39; includes additional HOA data - &#39;agreement&#39; information on the listing agreement - &#39;garageSpaces&#39; additional garage data - &#39;maintenanceExpense&#39; data on maintenance expenses - &#39;parking&#39; additional parking data - &#39;pool&#39; includes an additional pool description - &#39;taxAnnualAmount&#39; include the annual tax amount - &#39;taxYear&#39; include the tax year data - &#39;rooms&#39; include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available in the API response.  | [optional] 
 **sort** | **String**| Sort the response by a specific field. Values starting with a minus (-) denote descending order, while the others are ascending.  | [optional] 

### Return type

[**Array&lt;Listing&gt;**](Listing.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json, application/vnd.simplyrets-v0.1+json



# **properties_mls_id_get**
> Listing properties_mls_id_get(mls_id, opts)

Single Listing Endpoint

Use this endpoint for accessing a single listing. When you make a search to the `/properties` endpoint, each listing in the response will contain a unique `mlsId` field which should be used to request that listing on this route.  The `mlsId` field is a unique identifier for a listing which is specific to the SimplyRETS API only.  It is different from the `listingId` field is the public number given to a listing by the MLS and is not used here. 

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = SwaggerClient::DefaultApi.new

mls_id = 789 # Integer | The `mlsId` field is a unique identifier which is specific to the SimplyRETS API only.  This field is different from the `listingId` field (which is the public number given to a listing by the MLS and is not used here). 

opts = { 
  include: ["include_example"] # Array<String> | Include a extra fields which are not in the default response body - 'association' includes additional HOA data - 'agreement' information on the listing agreement - 'garageSpaces' additional garage data - 'maintenanceExpense' data on maintenance expenses - 'parking' additional parking data - 'pool' includes an additional pool description - 'rooms' include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available with valid data in the API response. If your MLS does not offer these fields, they will contain 'null'. 
}

begin
  #Single Listing Endpoint
  result = api_instance.properties_mls_id_get(mls_id, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling DefaultApi->properties_mls_id_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **mls_id** | **Integer**| The &#x60;mlsId&#x60; field is a unique identifier which is specific to the SimplyRETS API only.  This field is different from the &#x60;listingId&#x60; field (which is the public number given to a listing by the MLS and is not used here).  | 
 **include** | [**Array&lt;String&gt;**](String.md)| Include a extra fields which are not in the default response body - &#39;association&#39; includes additional HOA data - &#39;agreement&#39; information on the listing agreement - &#39;garageSpaces&#39; additional garage data - &#39;maintenanceExpense&#39; data on maintenance expenses - &#39;parking&#39; additional parking data - &#39;pool&#39; includes an additional pool description - &#39;rooms&#39; include parameter will include    any additional rooms as a list.  Note that your MLS must provide these fields in their RETS data for them to be available with valid data in the API response. If your MLS does not offer these fields, they will contain &#39;null&#39;.  | [optional] 

### Return type

[**Listing**](Listing.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json, application/vnd.simplyrets-v0.1+json



